@@ -1,3 +1,4 @@
+"""Binary Switches"""
 from datetime import datetime
 from typing import Callable
 
@@ -24,17 +25,17 @@ class BinarySwitchProperty(Property):
         super().__init__(element_uid=element_uid)
         self._setter = setter
 
-        self._state = kwargs.pop("state", False)
-        self.enabled = kwargs.pop("enabled", False)
+        self._state: bool = kwargs.pop("state", False)
+        self.enabled: bool = kwargs.pop("enabled", False)
 
     @property
     def state(self) -> bool:
-        """ State of the binary sensor. """
+        """State of the binary sensor."""
         return self._state
 
     @state.setter
     def state(self, state: bool):
-        """ Update state of the binary sensor and set point in time of the last_activity. """
+        """Update state of the binary sensor and set point in time of the last_activity."""
         self._state = state
         self._last_activity = datetime.now()
         self._logger.debug("State of %s set to %s.", self.element_uid, state)
