@@ -1,3 +1,4 @@
+"""Humidity Bars"""
 from datetime import datetime
 
 from ..exceptions.device import WrongElementError
@@ -21,12 +22,12 @@ class HumidityBarProperty(SensorProperty):
 
         super().__init__(element_uid=element_uid, **kwargs)
 
-        self._value = kwargs.pop("value", 0)
-        self.zone = kwargs.pop("zone", 0)
+        self._value: int = kwargs.pop("value", 0)
+        self.zone: int = kwargs.pop("zone", 0)
 
     @property
     def value(self) -> int:
-        """ Position inside a zone. """
+        """Position inside a zone."""
         return self._value
 
     @value.setter
