@@ -1,9 +1,10 @@
+"""Generic Sensors"""
 from abc import ABC
 
 from .property import Property
 
 
-class SensorProperty(Property, ABC):
+class SensorProperty(Property, ABC):  # pylint: disable=too-few-public-methods
     """
     Abstract object for sensors. It stores the sensor and sub type.
 
@@ -18,5 +19,5 @@ class SensorProperty(Property, ABC):
     def __init__(self, element_uid: str, **kwargs: str):
         super().__init__(element_uid=element_uid)
 
-        self.sensor_type = kwargs.pop("sensor_type", "")
-        self.sub_type = kwargs.pop("sub_type", "")
+        self.sensor_type: str = kwargs.pop("sensor_type", "")
+        self.sub_type: str = kwargs.pop("sub_type", "")
