@@ -1,5 +1,6 @@
+"""The Publisher"""
 import logging
-from typing import Callable, Dict, KeysView, Union
+from typing import Any, Callable, Dict, KeysView, List, Optional, Tuple, Union
 
 
 class Publisher:
@@ -7,25 +8,24 @@ class Publisher:
     The Publisher send messages to attached subscribers.
     """
 
-    def __init__(self, events: Union[list, KeysView]):
+    def __init__(self, events: Union[List[Any], KeysView]):
         self._logger = logging.getLogger(self.__class__.__name__)
-        self._events: Dict = {event: {}
-                              for event in events}
+        self._events: Dict[Any, Any] = {event: {} for event in events}
 
     def add_event(self, event: str):
-        """ Add a new event to listen to. """
+        """Add a new event to listen to."""
         self._events[event] = {}
 
     def delete_event(self, event: str):
-        """ Delete a not longer needed event. """
+        """Delete a not longer needed event."""
         self._events.pop(event)
 
-    def dispatch(self, event: str, message: tuple):
-        """ Dispatch the message to the subscribers. """
+    def dispatch(self, event: str, message: Tuple[Any, ...]):
+        """Dispatch the message to the subscribers."""
         for callback in self._get_subscribers_for_specific_event(event).values():
             callback(message)
 
-    def register(self, event: str, who: object, callback: Callable = None):
+    def register(self, event: str, who: Any, callback: Optional[Callable] = None):
         """
         As a new subscriber for an event, add a callback function to call on new message.
         If no callback is given, it registers update().
@@ -37,12 +37,11 @@ class Publisher:
         self._get_subscribers_for_specific_event(event)[who] = callback
         self._logger.debug("Subscriber registered for event %s", event)
 
-    def unregister(self, event: str, who: object):
-        """ Remove a subscriber for a specific event. """
+    def unregister(self, event: str, who: Any):
+        """Remove a subscriber for a specific event."""
         del self._get_subscribers_for_specific_event(event)[who]
         self._logger.debug("Subscriber deleted for event %s", event)
 
-    def _get_subscribers_for_specific_event(self, event: str) -> Dict:
-        """ All subscribers listening to an event. """
-        return self._events.get(event,
-                                {})
+    def _get_subscribers_for_specific_event(self, event: str) -> Dict[Any, Any]:
+        """All subscribers listening to an event."""
+        return self._events.get(event, {})
